% ----------------------------------------------------------------------- %
% % adjben function                                                     % %
% % actualrially adjust DB pension benefits to a new starting age       % %
% ----------------------------------------------------------------------- %

function adjfactor = adjben(origstart, newstart, gv, calc)

% initilization;
pv0 = 0; % present value of all future DB pension benefits if the individual starts to receive $1 benefit at original start age;
pv1 = 0; % present value of all future DB pension benefits if the individual starts to receive $1 benefit at new start age;
start = min(origstart, newstart); % earliest age to receive DB pension benefits between original start age and new start age;
 
% calcualate from gv.T;
% each period, the individual receives $1 as DB pension benefit if alive;
% discount the pension benefits backwards; 
% if paying DB pension benefits, the discount factor is 1 + gv.realrateg + gv.inflrate * (1 - gv.penadjrate);
% if no benefits is paid, the discount factor is 1 + gv.realrateg;
% benefits are paid only if the individual is alive, so need to take survival probabilities into account;
for age = 99 : -1 : start; % age;
    
    if age >= origstart
        pv0 = pv0 + 1;
    end;
    
    if age >= newstart;
        pv1 = pv1 + 1;
    end;
    
    if age >= start;
        
        if age > origstart;
            pv0 = pv0 * calc.srate(1, age - 25 + 1) / (1 + gv.realrateg + gv.inflrate * (1 - gv.penadjrate)); % pays DB benefits;
        else
            if age > start; % pays no DB pension benefits;
                pv0 = pv0 * calc.srate(1, age - 25 + 1) / (1 + gv.realrateg);
            end;
        end;

        if age > newstart;
            pv1 = pv1 * calc.srate(1, age - 25 + 1) / (1 + gv.realrateg + gv.inflrate * (1 - gv.penadjrate)); % pays DB benefits;
        else
            if age > start; % pays no DB pension benefits;
                pv1 = pv1 * calc.srate(1, age - 25 + 1) / (1 + gv.realrateg);
            end;
        end;
        
    end;

end;

% calculate the adjustment factor;
adjfactor = pv0 / pv1;

