% ----------------------------------------------------------------------- %
% % f function                                                          % %
% % evaluate the q-statistic for the moments                            % % 
% ----------------------------------------------------------------------- %

function [q, arglist] = f(sw, cparm, gv, oridata, arglist)

% print current set of parameter values;
cparm(1, 1) = gv.parm.sige;
cparm(2, 1) = gv.parm.erho;
cparm(3, 1) = gv.parm.beta0;
cparm(4, 1) = gv.parm.beta1;
cparm(5, 1) = gv.parm.beta2;
cparm(6, 1) = gv.parm.gamma0;
cparm(7, 1) = gv.parm.gamma1;
cparm(8, 1) = gv.parm.alpha;
fprintf('\n current parametes:');
fprintf('\n sige: %6.3f', cparm(1, 1));
fprintf('\n erho: %6.3f', cparm(2, 1));
fprintf('\n beta0: %6.3f', cparm(3, 1));
fprintf('\n beta1: %6.3f', cparm(4, 1));
fprintf('\n beta2: %6.3f', cparm(5, 1));
fprintf('\n gamma0: %6.3f', cparm(6, 1));
fprintf('\n gamma1: %6.3f', cparm(7, 1));
fprintf('\n alpha: %6.3f', cparm(8, 1));
fprintf('\n');

% if parameter values are out of range in the estimation, stop the program and return a large q;
if cparm(1, 1) <= 0.00001 || cparm(2, 1) <= -0.99999 || cparm(2, 1) >= 0.99999;
    q = 9e20;
    return;
end;

% if a new alpha is given, re-calculate rho;
if cparm(8, 1) ~= arglist.oldalphavalue; 
    arglist.newalpha = 1;
    arglist.oldalphavalue = cparm(8, 1); 
else
    arglist.newalpha = 0;
end;

%%%%%%%%%%%%%%%%%%%
% calculate model %
%%%%%%%%%%%%%%%%%%%
% run over individuals one by one;
% calculate retirement moments;
[arglist] = indivmodel(gv, oridata, arglist, cparm);   

% summarize results;
% initiliazation;
mvec = zeros(gv.nmoments, 1); % cumulative moment (difference between observed moments and simulated moments) vector;

% calculate cumulative moment vector;
for i = 1: gv.nmoments;
    for obs = 1 :  gv.nobs;
        mvec(i, 1) = mvec(i, 1) + arglist.mvec(obs, i);
    end;
end;

% reset weighting matrix;
if sw > 0;
    
    % initialization;
    winv = zeros(gv.nmoments * (gv.nmoments + 1) / 2, 1); % cumulative inverse weighting matrix;
    
    % calculate cumulative inverse weighting matrix;
    for i = 1 : gv.nmoments * (gv.nmoments + 1) / 2;
        for obs = 1 : gv.nobs;
            winv(i, 1) = winv(i, 1) + arglist.wmat(obs, i);
        end;
    end;
    
    % calculate weighting matrix (inverse winv);
    eps = 0.0000001;
    winv = invw(winv, eps, gv);
    
end;

% calculate q statistic;
q = 0;
l = 0;
for l1 = 1 : gv.nmoments;
    for l2 = 1 : l1;
        l = l + 1;
        if l1 == l2;
            q = q + mvec(l1, 1) * winv(l, 1) * mvec(l2, 1);
        else
            q = q + 2 * mvec(l1, 1) * winv(l, 1) * mvec(l2, 1);
        end;
    end;
end;

