% ----------------------------------------------------------------------- %
% % iter function                                                       % %
% % perform one evaluation of the objective function                    % %
% ----------------------------------------------------------------------- %

function iter(gv, oridata, arglist)

% initialization;
arglist.oldalphavalue = 0; % value of alpha, the consumption parameter, in last round of calculations;
arglist.newalpha = 1; % indicator of new value of consumption parameter alpha; if it is 1, re-calculate rho;


%%%%%%%%%%%%%%%%%%%
% calculate model %
%%%%%%%%%%%%%%%%%%%
% run f function to calculate results;
sw = 1; % if sw is 1, reset weighting matrix; if it is 0, keep the original weighting matrix;
[q, arglist] = f(sw, cparm, gv, oridata, arglist);


%%%%%%%%%%%%%%%%%%
% output results %
%%%%%%%%%%%%%%%%%%
% initialization;
ret1mat = zeros (21, 1); % percent of simulated workers who are not currently working full time; or are 1) currently in part time work; and 2) currently retired, by age (50 - 70);
ret2mat = zeros (21, 1); % percent of simulated workers who are currently retired;
everreturnft = 0; % percent of simulated workers ever return to full time work after full or partial retirement;
everreturnpt = 0; % percent of simulated workers ever return to part time work after full retirement;
everreturn = 0; % percent of simulated workers ever return to full time work after full or partial retirement, or return to part time work after full retirement;

% retrieve retirement moments from structure variable arglist;
% average over all households in iteration mode;
for age = 50 : 69;
    for obs = 1 : gv.nobs;
        ret1mat(age - 50 + 1, 1) = ret1mat(age - 50 + 1, 1) + arglist.ret1mat(obs, age - 50 + 1);
        ret2mat(age - 50 + 1, 1) = ret2mat(age - 50 + 1, 1) + arglist.ret2mat(obs, age - 50 + 1);
    end;
    ret1mat(age - 50 + 1, 1) = 100 * ret1mat(age - 50 + 1, 1) / gv.nobs;
    ret2mat(age - 50 + 1, 1) = 100 * ret2mat(age - 50 + 1, 1) / gv.nobs;
end;

for obs = 1 : gv.nobs;
    everreturnft = everreturnft + arglist.everreturnft(obs, 1);
    everreturnpt = everreturnpt + arglist.everreturnpt(obs, 1);
    everreturn = everreturn + arglist.everreturn(obs, 1);
end;
everreturnft = 100 * everreturnft / gv.nobs;
everreturnpt = 100 * everreturnpt / gv.nobs;
everreturn = 100 * everreturn / gv.nobs;

% print tabulations;
% ret1(age) - ret1(age - 1): increased percent of simulated workers who are not in full time job; Reversal jobs may be invovled;
% ret2(age) - ret2(age - 1): increased percent of simulated workers who are retired; Reversal jobs may be invovled;
% q: q statistic;
fprintf('\n\n                Percent                   Percent');
fprintf('\n            Pseudo-Retiring               Retired');
fprintf('\n           From                       From');
fprintf('\nAge       FT Work  Completely        FT Work  Completely');
fprintf('\n');
fprintf('\n 50                                  %5.1f     %5.1f', ret1mat(1, 1), ret2mat(1, 1));

for age = 51 : 69;
    fprintf('\n %2d       %5.1f    %5.1f             %5.1f     %5.1f', age,...
        ret1mat(age - 50 + 1, 1) - ret1mat((age - 1) - 50 + 1, 1), ret2mat(age - 50 + 1, 1) - ret2mat((age - 1) - 50 + 1, 1), ...
        ret1mat(age - 50 + 1, 1), ret2mat(age - 50 + 1, 1));
end;

fprintf('\n\n Percent returning to full time work after full or partial retirement: %5.1f', everreturnft);
fprintf('\n Percent returning to part time work after full retirement: %5.1f', everreturnpt);
fprintf('\n Percent returning to full time work after full or partial retirement');
fprintf('\n  or returning to part time work after full retirement: %5.1f', everreturn);
fprintf('\n\nnobs: %8d', gv.nobs);
fprintf('\nq: %11.3f', q);
fprintf('\n');











