% ----------------------------------------------------------------------- %
% % wealthcalc function                                                 % %
% % calculate differences between observed and simulated wealth         % %
% ----------------------------------------------------------------------- %

function wealthdiff = wealthcalc(gv, data, calc)

age92 = 1992 - data.birthyear; % age at 1992;

% initialization;
wealth = 0; % household asset;

for age = 25 : age92 - 1; % age;
    
    % wealth increases by observed real asset return;
    % if actual asset return not observed, use average asset return;
    year = age + data.birthyear;
    if year > 1926;
        wealth = (1 + 0.01 * gv.realrate((year - 1) - 1926 + 1, 1)) * wealth;
    elseif year <= 1926;
        wealth = (1 + gv.realrateg) * wealth;
    end;
    
    % find out the corresponding acat grid;
    acat = 1;
    while acat < gv.nacatlim && wealth > calc.acats(acat, 1);
        acat = acat + 1;
    end;
    if acat > 1;
        acat = acat - 1;
    end;
    
    % decide how much to consume given asset, assuming both spouses alive;
    % interpolation;
    c = ((calc.acats(acat + 1, 1) - wealth) * calc.cons(age - 25 + 1, 1, acat) ...
        + (wealth - calc.acats(acat, 1)) * calc.cons(age - 25 + 1, 1, acat + 1)) ...
        / (calc.acats(acat + 1, 1) - calc.acats(acat, 1));
    
    % calculate asset level next period; leftover asset + inflow - outflow;
    wealth = wealth + calc.income(1, age - 25 + 1) - c; % both spouses alive;
    
end;

% calculate wealth difference between observed asset and simulated asset;
if data.assetwealth > 0 || wealth > 0.1;
    wealthdiff = data.assetwealth - (1 + 0.01 * gv.realrate(1991 - 1926 + 1, 1)) * wealth; % observed 1992 asset - simulated 1992 asset;
else
    % setup boundary;
    wealthdiff = 0.1; 
end;



